@@ -10,11 +10,11 @@ Regexp::MultiLanguage::Perl - Perl dialect for Regexp::MultiLanguage.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 =head1 SYNOPSIS
 
@@ -54,6 +54,10 @@ sub function_call {
 	return "$prefix$name(\$_[0])";
 }
 
+=head1 AUTHOR
+
+Robby Walker, robwalker@cpan.org
+
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2006 Robby Walker, all rights reserved.
